@@ -12,7 +12,7 @@ use Sys::Syslog qw(:macros);
 use LISM::Storage;
 use Data::Dumper;
 
-our $VERSION = '2.1.7';
+our $VERSION = '2.1.8';
 
 our $lism_master = 'lism_master';
 our $syncrdn = 'cn=sync';
@@ -86,7 +86,7 @@ sub config
             $self->{_config}->{$k} = \@v;
         } else {
             if ($k eq 'admindn' || $k eq 'basedn') {
-                $self->{_config}->{$k} = lc $v[0];
+                ($self->{_config}->{$k} = $v[0]) =~ tr/A-Z/a-z/;
             } else {
                 $self->{_config}->{$k} = $v[0];
             }
@@ -225,7 +225,7 @@ sub bind
     }
 
     # check bind by administration user
-    $binddn = lc $binddn;
+    $binddn =~ tr/A-Z/a-z/;
     $binddn =~ s/,\s+/,/;
     if ($binddn =~ /^$self->{_config}->{admindn}$/i) {
         if (defined($self->{_config}->{adminpw}) && $passwd eq $self->{_config}->{adminpw}) {
@@ -310,6 +310,9 @@ sub search
     my($base, $scope, $deref, $sizeLim, $timeLim, $filterStr, $attrOnly, @attrs) = @_;
     my $conf = $self->{_lism};
 
+    # normalize dn
+    $base =~ tr/A-Z/a-z/;
+
     if (defined($conf->{sync})) {
         if ($base =~ /^($syncrdn|$master_syncrdn|$cluster_syncrdn),$self->{_config}->{basedn}$/i) {
             # get information of synchronization
@@ -336,7 +339,7 @@ sub compare
     my $conf = $self->{_lism};
     my $rc = LDAP_NO_SUCH_OBJECT;
 
-    $dn = lc $dn;
+    $dn =~ tr/A-Z/a-z/;
     $dn =~ s/,\s+/,/g;
 
     if ($dn eq $self->{_config}{basedn}) {
@@ -390,7 +393,7 @@ sub modify
     my $conf = $self->{_lism};
     my $rc;
 
-    $dn = lc $dn;
+    $dn =~ tr/A-Z/a-z/;
     $dn =~ s/,\s+/,/g;
 
     if ($dn eq $self->{_config}{basedn}) {
@@ -439,7 +442,7 @@ sub add
     }
 
     $entryStr =~ s/^dn:.*\n//;
-    $dn = lc $dn ;
+    $dn =~ tr/A-Z/a-z/;
     $dn =~ s/,\s+/,/g;
 
     if ($dn eq $self->{_config}{basedn}) {
@@ -481,7 +484,7 @@ sub modrdn
     my $conf = $self->{_lism};
     my $rc;
 
-    $dn = lc $dn;
+    $dn =~ tr/A-Z/a-z/;
     $dn =~ s/,\s+/,/g;
 
     if ($dn eq $self->{_config}{basedn}) {
@@ -515,7 +518,7 @@ sub delete
     my $conf = $self->{_lism};
     my $rc;
 
-    $dn = lc $dn ;
+    $dn =~ tr/A-Z/a-z/;
     $dn =~ s/,\s+/,/g;
 
     if ($dn eq $self->{_config}{basedn}) {
@@ -586,7 +589,8 @@ sub _checkConfig
             return 1;
         }
         # normalize dn
-        $self->{data}{$dname}->{suffix} = lc $dconf->{container}[0]->{rdn}[0].','.$conf->{basedn};
+        $dconf->{container}[0]->{rdn}[0] =~ tr/A-Z/a-z/;
+        $self->{data}{$dname}->{suffix} = $dconf->{container}[0]->{rdn}[0].','.$conf->{basedn};
 
         # set container entry
         my $entry;
@@ -614,7 +618,7 @@ sub _checkConfig
 
             # normalize dn
             my $master_suffix = $sync->{master}[0]->{containerdn}[0].','.$conf->{basedn};
-            $master->{suffix} = lc $master_suffix;
+            ($master->{suffix} = $master_suffix) =~ tr/A-Z/a-z/;
             ($master->{contentrystr} = $src_data->{contentrystr}) =~ s/$src_data->{suffix}$/$master_suffix/mi;
             $master->{conf} = $src_data->{conf};
         }
@@ -647,12 +651,12 @@ sub _checkConfig
                 # nomalize dn
                 if (defined($sobject->{syncdn})) {
                     for (my $i = 0; $i < @{$sobject->{syncdn}}; $i++) {
-                        $sobject->{syncdn}[$i] = lc $sobject->{syncdn}[$i];
+                        $sobject->{syncdn}[$i] =~ tr/A-Z/a-z/;
                     }
                 }
                 if (defined($sobject->{masterdn})) {
                     for (my $i = 0; $i < @{$sobject->{masterdn}}; $i++) {
-                        $sobject->{masterdn}[$i] = lc $sobject->{masterdn}[$i];
+                        $sobject->{masterdn}[$i] =~ tr/A-Z/a-z/;
                     }
                 }
 
@@ -770,8 +774,12 @@ sub _do_search
         ($rc, @subentries) = $storage->search($srchbase, $scope, $deref, $sizeLim, $timeLim, $dfilterStr, $attrOnly, @attrs);
         if ($rc == LDAP_SERVER_DOWN) {
             $self->log(level => 'error', message => "Searching in $dname failed($rc)");
-            $rc = LDAP_SUCCESS;
-            next;
+            if ($base =~ /^$self->{_config}->{basedn}$/i) {
+                $rc = LDAP_SUCCESS;
+                next;
+            } else {
+                last;
+            }
         } elsif ($rc) {
             last;
         }
@@ -1200,7 +1208,7 @@ sub _doSync
 
         # replace dn to dn in the data entry
         $ddn =~ s/$master->{suffix}$/$data->{suffix}/i;
-        $ddn = lc($ddn);
+        $ddn =~ tr/A-Z/a-z/;
 
         # replicate to the storage
         $rc = $self->_doUpdate($func, undef, 0, $ddn, @dinfo);
@@ -1351,11 +1359,12 @@ sub _getSyncInfo
                     # comare data storage's values with master one
                     for (my $i = 0; $i < @entries; $i++) {
                         my ($dn) = ($entries[$i] =~ /^dn: (.*)\n/);
+                        $dn =~ tr/A-Z/a-z/;
+
                         my ($key) = ($dn =~ /^(.*),$dbase$/i);
                         if (!$key) {
                             next;
                         }
-                        $key = lc($key);
 
                         # check need for synchronization
                         if (defined($masterfilter) &&
@@ -1367,7 +1376,7 @@ sub _getSyncInfo
                             # data storage's entry doesn't exist in master storage
                             if ($ops{add}) {
                                 $nosync_data{$dname} = 1;
-                                $nosync_entries{lc($dn)} = 1;
+                                $nosync_entries{$dn} = 1;
                             }
                         } else {
                             if (!defined($sobject->{masterattrs})) {
@@ -1400,7 +1409,7 @@ sub _getSyncInfo
                                 $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ /^$pvals$/i && $ops{modify}) {
                                     $nosync_data{$dname} = 1;
-                                    $nosync_entries{lc($dn)} = 1;
+                                    $nosync_entries{$dn} = 1;
                                     last;
                                 }
                             }
@@ -1430,7 +1439,9 @@ sub _getSyncInfo
                         !LISM::Storage->parseFilter($masterfilter, $present_list->{$sbase}{$key}->{entryStr})) {
                         next;
                     }
-                    $nosync_entries{lc("$key,$sbase")} = 1;
+                    my $nosync_entry = "$key,$sbase";
+                    $nosync_entry =~ tr/A-Z/a-z/;
+                    $nosync_entries{$nosync_entry} = 1;
                 }
             }
         }
@@ -1483,17 +1494,18 @@ sub _getSyncInfo
                     # comare data storage's values with master one
                     for (my $i = 0; $i < @entries; $i++) {
                         my ($dn) = ($entries[$i] =~ /^dn: (.*)\n/);
+                        $dn =~ tr/A-Z/a-z/;
+
                         my ($key) = ($dn =~ /^(.*),$dbase$/i);
                         if (!$key) {
                             next;
                         }
-                        $key = lc($key);
 
                         if (!defined($present_list->{$sbase}{$key})) {
                             # data storage's entry doesn't exist in master storage
                             if ($ops{delete}) {
                                 $nosync_data{$dname} = 1;
-                                $nosync_entries{lc($dn)} = 1;
+                                $nosync_entries{$dn} = 1;
                             }
                         } elsif ($present_list->{$sbase}{$key} && !defined($syncfilter) ||
                                 LISM::Storage->parseFilter($syncfilter, $present_list->{$sbase}{$key}->{entryStr})) {
@@ -1531,7 +1543,7 @@ sub _getSyncInfo
                                 $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ /^$pvals$/i && $ops{modify}) {
                                     $nosync_data{$dname} = 1;
-                                    $nosync_entries{lc($dn)} = 1;
+                                    $nosync_entries{$dn} = 1;
                                     last;
                                 }
                             }
@@ -1548,8 +1560,10 @@ sub _getSyncInfo
                             if (!defined($present_list->{$sbase}{$key}->{sync_present}{$dname}) &&
                                 (!defined($syncfilter) ||
                                     LISM::Storage->parseFilter($syncfilter, $present_list->{$sbase}{$key}->{entryStr}))) {
+                                my $nosync_entry = "$key,$dbase";
+                                $nosync_entry =~ tr/A-Z/a-z/;
                                 $nosync_data{$dname} = 1;
-                                $nosync_entries{lc("$key,$dbase")} = 1;
+                                $nosync_entries{$nosync_entry} = 1;
                             }
                         }
                     }
@@ -1671,7 +1685,7 @@ sub _setSyncInfo
                         if (!$key) {
                             next;
                         }
-                        $key = lc($key);
+                        $key =~ tr/A-Z/a-z/;
 
                         my $dn = "$key,$sbase";
                         if (!defined($present_list->{$sbase}{$key})) {
@@ -1897,11 +1911,12 @@ sub _setSyncInfo
                     # comare data storage's values with master one
                     for (my $i = 0; $i < @entries; $i++) {
                         my ($dn) = ($entries[$i] =~ /^dn: (.*)\n/);
+                        $dn =~ tr/A-Z/a-z/;
+
                         my ($key) = ($dn =~ /^(.*),$dbase$/i);
                         if (!$key) {
                             next;
                         }
-                        $key = lc($key);
 
                         if (!defined($present_list->{$sbase}{$key})) {
                             if ($ops{delete}) {
@@ -2076,7 +2091,7 @@ sub _getPresentList
                         if (!$key) {
                             next;
                         }
-                        $key = lc($key);
+                        $key =~ tr/A-Z/a-z/;
 
                         my $entryStr;
                         ($entryStr = $entries[$i]) =~ s/^dn:.*\n//;
