@@ -84,6 +84,21 @@ sub _checkConfig
         }
     }
 
+    if (defined($conf->{entry})) {
+        foreach my $entry (@{$conf->{entry}}) {
+            if (defined($entry->{default})) {
+                foreach my $attr (keys %{$entry->{default}}) {
+                    # check type of value
+                    if (defined($entry->{default}{$attr}->{value}) && 
+                        !ref($entry->{default}{$attr}->{value}[0])) {
+                        $self->log(level => 'alert', message => "type of setval default value doesn't exist");
+                        return 1;
+                    }
+                }
+            }
+        }
+    }
+
     return $rc;
 }
 
