@@ -669,12 +669,13 @@ sub _checkConfig
                 $self->log(level => 'alert', message => "$oname object container entry is invalid");
                 return 1;
             } else {
-                my $crdn = lc($oconf->{container}[0]->{rdn}[0]);
+                $oconf->{container}[0]->{rdn}[0] =~ tr/A-Z/a-z/;
+                my $crdn = $oconf->{container}[0]->{rdn}[0];
                 my $coname = $crdn.'_container';
                 if (!defined($self->{object}{$coname})) {
                     $self->{object}{$coname}->{entrystr} = $entry;
                     # normalize suffix
-                    $self->{object}{$coname}->{suffix} = lc("$crdn,".$self->{suffix});
+                    ($self->{object}{$coname}->{suffix} = "$crdn,".$self->{suffix}) =~ tr/A-Z/a-z/;
                 }
                 # set child object
                 if (!defined($self->{object}{$coname}->{child})) {
