@@ -402,7 +402,7 @@ sub _objModify
                     last DO;
                 } else {
                     my $value = $values[0];
-                    $value =~ s/([.*+?\[\]])/\\$1/g;
+                    $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                     if ($entry !~ /^$attr: $value$/mi) {
                         $rc = LDAP_CONSTRAINT_VIOLATION;
                         last DO;
@@ -421,7 +421,7 @@ sub _objModify
             if($action eq "ADD") {
                 # check whether the value already exists
                 my $vals_str = "(".join('|', @values).")";
-                $vals_str =~ s/([.*+?\[\]])/\\$1/g;
+                $vals_str =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                 if ($entry =~ /^$attr: $vals_str *$/mi) {
                     $rc = LDAP_TYPE_OR_VALUE_EXISTS;
                     last DO;
@@ -459,7 +459,7 @@ sub _objModify
                 # check whether the value exists
                 for (my $i = 0; $i < @values; $i++) {
                     my $value = $values[$i];
-                    $value =~ s/([.*+?\[\]])/\\$1/g;
+                    $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                     if ($value && $entry !~ /^$attr: $value *$/mi) {
                         $rc = LDAP_NO_SUCH_ATTRIBUTE;
                         last DO;
@@ -529,7 +529,7 @@ sub _objModify
                         my $match = 0;
                         for (my $i = 0; $i < @values; $i++) {
                             my $value = $values[$i];
-                            $value =~ s/([.*+?\[\]])/\\$1/g;
+                            $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                             if ($old_val =~ /^$value$/i) {
                                 $match = 1;
                                 next;
@@ -553,7 +553,7 @@ sub _objModify
                     # add the new values doesn't exist
                     for (my $i = 0; $i < @values; $i++) {
                         my $value = $values[$i];
-                        $value =~ s/([.*+?\[\]])/\\$1/g;
+                        $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                         if (grep(/^$value$/i, @existing_vals)) {
                             next;
                         }
